@@ -26,7 +26,10 @@
 #include <libxfcegui4/netk-screen.h>
 #include <libxfcegui4/netk-util.h>
 #include <libxfcegui4/netk-window.h>
+#include <libxfcegui4/netk-window-action-menu.h>
 #include <libxfcegui4/netk-workspace.h>
+#include <libxfcegui4/netk-class-group.h>
+#include <libxfcegui4/netk-trayicon.h>
 #include <libxfcegui4/netk-enum-types.h>
 
 #include <libxfcegui4/netk-pager.h>
